@@ -2,7 +2,7 @@
 
 use std::{fmt, marker::PhantomData, mem, ptr};
 
-use crate::translate::*;
+use crate::{ffi, translate::*};
 
 // rustdoc-stripper-ignore-next
 /// Minimum size of the `PtrSlice` allocation.
@@ -11,7 +11,7 @@ const MIN_SIZE: usize = 16;
 // rustdoc-stripper-ignore-next
 /// Slice of elements of type `T` allocated by the GLib allocator.
 ///
-/// The underlying memory is always `NULL`-terminated. [`Slice<T>`]
+/// The underlying memory is always `NULL`-terminated. [`Slice<T>`](crate::collections::slice::Slice)
 /// can be used for a non-`NULL`-terminated slice.
 ///
 /// This can be used like a `&[T]`, `&mut [T]` and `Vec<T>`.
@@ -718,6 +718,12 @@ impl<T: TransparentPtrType> PtrSlice<T> {
             let new_ptr =
                 ffi::g_realloc(ptr, mem::size_of::<T>().checked_mul(new_capacity).unwrap())
                     as *mut <T as GlibPtrDefault>::GlibType;
+            if self.capacity == 0 {
+                ptr::write(
+                    new_ptr,
+                    Ptr::from(ptr::null_mut::<<T as GlibPtrDefault>::GlibType>()),
+                );
+            }
             self.ptr = ptr::NonNull::new_unchecked(new_ptr);
             self.capacity = new_capacity;
         }
@@ -1072,7 +1078,7 @@ impl<T: TransparentPtrType> From<super::Slice<T>> for PtrSlice<T> {
 }
 
 // rustdoc-stripper-ignore-next
-/// A trait to accept both <code>&[T]</code> or <code>PtrSlice<T></code> as an argument.
+/// A trait to accept both `&[T]` or `PtrSlice<T>` as an argument.
 pub trait IntoPtrSlice<T: TransparentPtrType> {
     // rustdoc-stripper-ignore-next
     /// Runs the given closure with a `NULL`-terminated array.
