@@ -2,7 +2,7 @@
 
 use std::{ffi::c_char, fmt, marker::PhantomData, mem, ptr};
 
-use crate::{prelude::*, translate::*, GStr, GString, GStringPtr};
+use crate::{ffi, gobject_ffi, prelude::*, translate::*, GStr, GString, GStringPtr};
 
 // rustdoc-stripper-ignore-next
 /// Minimum size of the `StrV` allocation.
@@ -343,6 +343,22 @@ impl<const N: usize> From<[GString; N]> for StrV {
     }
 }
 
+impl<const N: usize> From<[String; N]> for StrV {
+    #[inline]
+    fn from(value: [String; N]) -> Self {
+        unsafe {
+            let len = value.len();
+            let mut s = Self::with_capacity(len);
+            for (i, v) in value.into_iter().enumerate() {
+                *s.ptr.as_ptr().add(i) = GString::from(v).into_glib_ptr();
+            }
+            s.len = len;
+            *s.ptr.as_ptr().add(s.len) = ptr::null_mut();
+            s
+        }
+    }
+}
+
 impl<'a, const N: usize> From<[&'a str; N]> for StrV {
     #[inline]
     fn from(value: [&'a str; N]) -> Self {
@@ -698,6 +714,9 @@ impl StrV {
                     .checked_mul(new_capacity)
                     .unwrap(),
             ) as *mut *mut c_char;
+            if self.capacity == 0 {
+                *new_ptr = ptr::null_mut();
+            }
             self.ptr = ptr::NonNull::new_unchecked(new_ptr);
             self.capacity = new_capacity;
         }
